@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # vim: set ts=4 sw=4 expandtab sts=4:
 # Copyright (c) 2011-2013 Christian Geier & contributors
 #
@@ -21,12 +21,11 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
-contains the class PyCardDAV and some associated functions and definitions
+contains the class PyCardDAv and some associated functions and definitions
 """
 
 from collections import namedtuple
 import requests
-import sys
 import urlparse
 import logging
 import lxml.etree as ET
@@ -42,16 +41,16 @@ def get_random_href():
     return "-".join(tmp_list).upper()
 
 
-DAVICAL = 'davical'
-SABREDAV = 'sabredav'
-UNKNOWN = 'unknown server'
-
-
 class UploadFailed(Exception):
     """uploading the card failed"""
     pass
 
 
+class NoWriteSupport(Exception):
+    """write support has not been enabled"""
+    pass
+
+
 class PyCardDAV(object):
     """class for interacting with a CardDAV server
 
@@ -91,11 +90,16 @@ class PyCardDAV(object):
             from requests.auth import HTTPDigestAuth
             self._settings['auth'] = HTTPDigestAuth(user, passwd)
         self._default_headers = {"User-Agent": "pyCardDAV"}
-        response = self.session.request('PROPFIND', resource,
-                                        headers=self.headers,
+
+        headers = self.headers
+        headers['Depth'] = '1'
+        response = self.session.request('OPTIONS',
+                                        self.url.resource,
+                                        headers=headers,
                                         **self._settings)
         response.raise_for_status()   #raises error on not 2XX HTTP status code
-
+        if response.headers['DAV'].count('addressbook') == 0:
+            raise Exception("URL is not a CardDAV resource")
 
     @property
     def verify(self):
@@ -109,32 +113,13 @@ class PyCardDAV(object):
 
     @property
     def headers(self):
+        """returns the headers"""
         return dict(self._default_headers)
 
     def _check_write_support(self):
         """checks if user really wants his data destroyed"""
         if not self.write_support:
-            sys.stderr.write("Sorry, no write support for you. Please check "
-                             "the documentation.\n")
-            sys.exit(1)
-
-    def _detect_server(self):
-        """detects CardDAV server type
-
-        currently supports davical and sabredav (same as owncloud)
-        :rtype: string "davical" or "sabredav"
-        """
-        response = requests.request('OPTIONS',
-                                    self.url.base,
-                                    headers=self.header)
-        if "X-Sabre-Version" in response.headers:
-            server = SABREDAV
-        elif "X-DAViCal-Version" in response.headers:
-            server = DAVICAL
-        else:
-            server = UNKNOWN
-        logging.info(server + " detected")
-        return server
+            raise NoWriteSupport
 
     def get_abook(self):
         """does the propfind and processes what it returns
@@ -193,9 +178,9 @@ class PyCardDAV(object):
         headers['content-type'] = 'text/vcard'
         if etag is not None:
             headers['If-Match'] = etag
-        result = self.session.delete(remotepath,
-                                     headers=headers,
-                                     **self._settings)
+        response = self.session.delete(remotepath,
+                                       headers=headers,
+                                       **self._settings)
         response.raise_for_status()
 
     def upload_new_card(self, card):
@@ -213,7 +198,8 @@ class PyCardDAV(object):
             rand_string = get_random_href()
             remotepath = str(self.url.resource + rand_string + ".vcf")
             headers = self.headers
-            headers['content-type'] = 'text/vcard'
+            headers['content-type'] = 'text/vcard'  # TODO perhaps this should
+            # be set to the value this carddav server uses itself
             headers['If-None-Match'] = '*'
             response = requests.put(remotepath, data=card, headers=headers,
                                     **self._settings)
@@ -242,8 +228,6 @@ class PyCardDAV(object):
                                         headers=headers,
                                         **self._settings)
         response.raise_for_status()
-        if response.headers['DAV'].count('addressbook') == 0:
-            raise Exception("URL is not a CardDAV resource")
 
         return response.content
 
@@ -269,10 +253,16 @@ class PyCardDAV(object):
                         href = refprop.text
                     for prop in refprop.iterchildren():
                         for props in prop.iterchildren():
+                            # different servers give different getcontenttypes:
+                            # e.g.:
+                            #  "text/vcard"
+                            #  "text/x-vcard"
+                            #  "text/x-vcard; charset=utf-8"
+                            #  "text/directory;profile=vCard"
+                            #  "text/directory"
+                            #  "text/vcard; charset=utf-8"  CalendarServer
                             if (props.tag == namespace + "getcontenttype" and
-                                (props.text == "text/vcard" or
-                                 props.text == "text/x-vcard" or
-                                 props.text == "text/x-vcard; charset=utf-8")):
+                                props.text.split(';')[0].strip() in ['text/vcard', 'text/x-vcard']):
                                 insert = True
                             if (props.tag == namespace + "getetag"):
                                 etag = props.text
